/*
 *  $Id: pvrusb2-hdw-low.h,v 1.2 2005/04/27 05:26:39 isely Exp $
 *
 *  Copyright (C) 2005 Mike Isely <isely@pobox.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */
#ifndef __PVRUSB2_HDW_LOW_H
#define __PVRUSB2_HDW_LOW_H

#include <linux/types.h>
#include "pvrusb2-hdw.h"

#define PVR2_DECOMPOSE_LE(t,i,d) \
    do {    \
        (t)[i] = (d) & 0xff;\
        (t)[i+1] = ((d) >> 8) & 0xff;\
        (t)[i+2] = ((d) >> 16) & 0xff;\
        (t)[i+3] = ((d) >> 24) & 0xff;\
    } while(0)

#define PVR2_DECOMPOSE_BE(t,i,d) \
    do {    \
        (t)[i+3] = (d) & 0xff;\
        (t)[i+2] = ((d) >> 8) & 0xff;\
        (t)[i+1] = ((d) >> 16) & 0xff;\
        (t)[i] = ((d) >> 24) & 0xff;\
    } while(0)

#define PVR2_SIZEOF_CMD(c)   (2*sizeof(short)+sizeof(char)*(c)->length)
#define PVR2_CMD(r,c)   { .length = sizeof(c)-1, .ret = r , .cmd = c }
#define PVR2_DECLARE_CMD(name,r,c) struct pvr2_cmd name = PVR2_CMD(r,c)

struct pvr2_cmd {
    u8 length;
    u8 ret;
    u8 *cmd;
};

void pvr2_reset_ctl_endpoints(struct pvr2_hdw *hdw);

int pvr2_send_sequence(struct pvr2_hdw *, struct pvr2_cmd *);
int pvr2_send_request(struct pvr2_hdw *, void *, unsigned int,
		      void *, unsigned int);
int pvr2_do_command(struct pvr2_hdw *, struct pvr2_cmd *);

int pvr2_write_register(struct pvr2_hdw *, u16, u32);
int pvr2_read_register(struct pvr2_hdw *, u16, u32 *);
int pvr2_write_u16(struct pvr2_hdw *, u16, int);
int pvr2_write_u8(struct pvr2_hdw *, u8, int);

/* Call if for any reason we can't talk to the hardware anymore */
void pvr2_hdw_render_useless(struct pvr2_hdw *);

#endif /* __PVRUSB2_HDW_LOW_H */
/*
  Stuff for Emacs to see, in order to encourage consistent editing style:
  *** Local Variables: ***
  *** mode: c ***
  *** fill-column: 75 ***
  *** c-basic-offset: 4 ***
  *** indent-tabs-mode: nil ***
  *** End: ***

  Similarly for vim to see:
  vim:expandtab:textwidth=75

*/
